@@ -1,5 +1,5 @@
-require 'recycle'
 require 'racc/scanner'
+require 'amstd/recycle'
 
 #
 # mailp.rb
