@@ -77,7 +77,7 @@
 
             if DIGIT === vret then
               sret = :DIGIT
-              vret = vret.to_i
+              vret = vret
 
             elsif @m_recv = MODE_RECV then
               case vret.downcase
